@@ -69,6 +69,7 @@ def process_artifacts_from_answers(
     ],
     write: bool = True,
     verbose: bool = False,
+    filter_types: Optional[List[str]] = None,
 ) -> Generator[Tuple[str, generation.Artifact], None, None]:
     """
     Process the Artifacts from the Answers.
@@ -98,12 +99,17 @@ def process_artifacts_from_answers(
                 ext = ".pb"
                 contents = artifact.SerializeToString()
             out_p = truncate_fit(prefix, prompt, ext, int(artifact_start), idx, MAX_FILENAME_SZ)
+            is_allowed_type = filter_types is None or artifact_type_to_str(artifact.type) in filter_types
             if write:
-                with open(out_p, "wb") as f:
-                    f.write(bytes(contents))
+                if is_allowed_type:
+                    with open(out_p, "wb") as f:
+                        f.write(bytes(contents))
+                        if verbose:
+                            logger.info(f"wrote {artifact_type_to_str(artifact.type)} to {out_p}")
+                else:
                     if verbose:
-                        artifact_t = artifact_type_to_str(artifact.type)
-                        logger.info(f"wrote {artifact_t} to {out_p}")
+                        logger.info(
+                            f"skipping {artifact_type_to_str(artifact.type)} due to artifact type filter")
 
             yield (out_p, artifact)
             idx += 1
@@ -333,7 +339,7 @@ class StabilityInference:
                         for artifact in answer.artifacts
                     ]
                     logger.info(
-                        f"Got {answer.answer_id} with {artifact_ts} in "
+                        f"Got answer {answer.answer_id} with artifact types {artifact_ts} in "
                         f"{duration:0.2f}s"
                     )
                 else:
@@ -418,6 +424,13 @@ if __name__ == "__main__":
         default="generation_",
         help="output prefixes for artifacts",
     )
+    parser.add_argument(
+        "--artifact_types",
+        "-t",
+        action='append',
+        type=str,
+        help="filter artifacts by type (ARTIFACT_IMAGE, ARTIFACT_TEXT, ARTIFACT_CLASSIFICATIONS, etc)"
+    )
     parser.add_argument(
         "--no-store", action="store_true", help="do not write out artifacts"
     )
@@ -484,7 +497,8 @@ if __name__ == "__main__":
 
     answers = stability_api.generate(args.prompt, **request)
     artifacts = process_artifacts_from_answers(
-        args.prefix, args.prompt, answers, write=not args.no_store, verbose=True
+        args.prefix, args.prompt, answers, write=not args.no_store, verbose=True,
+        filter_types=args.artifact_types,
     )
     if args.show:
         for artifact in open_images(artifacts, verbose=True):
